const { TEAMCO_BASE_URL } = require("../const.js");

/**
 * @description: 将对象转可拼接到 url 后的字符串
 * @param {Object} data
 * @return {*}
 */
const getQueryString = (data) => {
  let paramsArr = [];
  if (data && data instanceof Object) {
    Object.keys(data).forEach((key) => {
      let val = data[key]
      paramsArr.push(encodeURIComponent(key) + '=' + encodeURIComponent(val));
    })
    return '?' + paramsArr.join('&')
  }
  return ''
}

/**
 * @description: 简单封装 XMLHttpRequest
 * @param {*} settings
 * @return {*}
 */
function xhrBinary(settings) {
  const headers = settings.headers || {};
  let reqCfg = {
    url: '',
    method: '',
    data: null,
    timeout: 10000,
    ...settings,
    headers: {
      'Content-Type': "application/json",
      ...headers
    }
  }
  return new Promise((resolve, reject) => {
    let xhr = new XMLHttpRequest();
    xhr.onreadystatechange = function () {
      if (xhr.readyState == 4) {
        //根据服务器的响应内容格式处理响应结果
        if (xhr.getResponseHeader("content-type") === "application/json") {
          const result = JSON.parse(xhr.responseText);
          resolve(result);
          //根据返回结果判断验证码是否正确
          if (result.code === -1) {
            reject("验证码错误");
          }
        } else {
          reject(xhr.responseText);
        }
      }
    };
    xhr.onerror = reject;
    xhr.onabort = reject;
    xhr.open(reqCfg.method, reqCfg.url, true);
    const token = localStorage.getItem("teamco_access_token") ? localStorage.getItem("teamco_access_token") : "";
    xhr.setRequestHeader("token", token);
    for (const key of Object.keys(reqCfg.headers)) {
      xhr.setRequestHeader(key, reqCfg.headers[key])
    }
    xhr.send(reqCfg.data);
  });
}

const api = {
  post(url, data) {
    const settings = {
      url: TEAMCO_BASE_URL + url,
      method: "POST",
      data: JSON.stringify(data)
    }
    return xhrBinary(settings);
  },
  get(url, data) {
    const settings = {
      url: TEAMCO_BASE_URL + url + getQueryString(data),
      method: "GET",
      headers: {
        'Content-Type': "application/x-www-form-urlencoded"
      }
    };
    return xhrBinary(settings)
  }
}

export default api;
